==> ui-framework-4.5.4-sources.jar: io/intino/alexandria/schemas/DynamicTableSection.java <==
package io.intino.alexandria.schemas;

import io.intino.alexandria.schemas.*;

public class DynamicTableSection implements java.io.Serializable {

	private String label;
	private String color;
	private String backgroundColor;
	private int fontSize = 0;
	private java.util.List<DynamicTableSection> sections = new java.util.ArrayList<>();
	private java.util.List<DynamicTableColumn> columns = new java.util.ArrayList<>();
	private java.util.List<DynamicTableRow> rows = new java.util.ArrayList<>();

	public String label() {
		return this.label;
	}

	public String color() {
		return this.color;
	}

	public String backgroundColor() {
		return this.backgroundColor;
	}

	public int fontSize() {
		return this.fontSize;
	}

	public java.util.List<DynamicTableSection> sections() {
		return this.sections;
	}

	public java.util.List<DynamicTableColumn> columns() {
		return this.columns;
	}

	public java.util.List<DynamicTableRow> rows() {
		return this.rows;
	}

	public DynamicTableSection label(String label) {
		this.label = label;
		return this;
	}

	public DynamicTableSection color(String color) {
		this.color = color;
		return this;
	}

	public DynamicTableSection backgroundColor(String backgroundColor) {
		this.backgroundColor = backgroundColor;
		return this;
	}

	public DynamicTableSection fontSize(int fontSize) {
		this.fontSize = fontSize;
		return this;
	}

	public DynamicTableSection sections(java.util.List<DynamicTableSection> sections) {
		this.sections = sections;
		return this;
	}

	public DynamicTableSection columns(java.util.List<DynamicTableColumn> columns) {
		this.columns = columns;
		return this;
	}

	public DynamicTableSection rows(java.util.List<DynamicTableRow> rows) {
		this.rows = rows;
		return this;
	}
}

==> ui-framework-4.17.9-sources.jar: io/intino/alexandria/schemas/DynamicTableSection.java <==
package io.intino.alexandria.schemas;

import io.intino.alexandria.schemas.*;

public class DynamicTableSection implements java.io.Serializable {

	private String label;
	private String color;
	private String backgroundColor;
	private int fontSize = 0;
	private Boolean isOrdinal = false;
	private java.util.List<DynamicTableSection> sections = new java.util.ArrayList<>();
	private java.util.List<DynamicTableColumn> columns = new java.util.ArrayList<>();
	private java.util.List<DynamicTableRow> rows = new java.util.ArrayList<>();

	public String label() {
		return this.label;
	}

	public String color() {
		return this.color;
	}

	public String backgroundColor() {
		return this.backgroundColor;
	}

	public int fontSize() {
		return this.fontSize;
	}

	public Boolean isOrdinal() {
		return this.isOrdinal;
	}

	public java.util.List<DynamicTableSection> sections() {
		return this.sections;
	}

	public java.util.List<DynamicTableColumn> columns() {
		return this.columns;
	}

	public java.util.List<DynamicTableRow> rows() {
		return this.rows;
	}

	public DynamicTableSection label(String label) {
		this.label = label;
		return this;
	}

	public DynamicTableSection color(String color) {
		this.color = color;
		return this;
	}

	public DynamicTableSection backgroundColor(String backgroundColor) {
		this.backgroundColor = backgroundColor;
		return this;
	}

	public DynamicTableSection fontSize(int fontSize) {
		this.fontSize = fontSize;
		return this;
	}

	public DynamicTableSection isOrdinal(Boolean isOrdinal) {
		this.isOrdinal = isOrdinal;
		return this;
	}

	public DynamicTableSection sections(java.util.List<DynamicTableSection> sections) {
		this.sections = sections;
		return this;
	}

	public DynamicTableSection columns(java.util.List<DynamicTableColumn> columns) {
		this.columns = columns;
		return this;
	}

	public DynamicTableSection rows(java.util.List<DynamicTableRow> rows) {
		this.rows = rows;
		return this;
	}
}
